import { FC } from 'react';
import { SpeakableSpecification } from 'schema-dts';
import { DeferSeoProps } from '../types';
import { Overrides, Speakable } from '../utils/shared-types';
/**
 * The Speakable JSON LD Component props.
 */
export interface SpeakableJsonLdProps extends DeferSeoProps, Speakable, Overrides<SpeakableSpecification> {
}
/**
 * The speakable schema.org property identifies sections within an article or
 * webpage that are best suited for audio playback using text-to-speech (TTS).
 *
 * @remarks
 *
 * Adding markup allows search engines and other applications to identify
 * content to read aloud on Google Assistant-enabled devices using TTS. Webpages
 * with speakable structured data can use the Google Assistant to distribute the
 * content through new channels and reach a wider base of users.
 *
 * ``` tsx
 * const Component = () => <SpeakableJsonLd cssSelector={['#abc', '#root']} />;
 * ```
 *
 * @beta
 */
export declare const SpeakableJsonLd: FC<SpeakableJsonLdProps>;
//# sourceMappingURL=speakable.d.ts.map